
import java.awt.*;
import java.awt.image.*;
import java.io.*;
import javax.imageio.*;

public class GraphicsTo32BitRaw {

	public static void main(String args[]) throws Exception {
		// check arguments
		if (args.length != 1) {
			System.out.println("Usage: java GraphicsTo16BitRaw pic.png");
			return;
		}

		// load image
		String filename = args[0];
		Image image = ImageIO.read(new File(filename));

		// determine pixels
		int w = image.getWidth(null);
		int h = image.getHeight(null);
		int[] pixels = new int[w * h];
		PixelGrabber pg = new PixelGrabber(image, 0, 0, w, h, pixels, 0, w);
		try {
			pg.grabPixels();
		} catch (InterruptedException e) {
		}

		// save as raw data
		try {
			// create pixels buffer
			byte [] outBuffer = new byte[w*h*4];
			int i = 0;
			for (int y = 0; y < h; y++) {
				StringBuffer line = new StringBuffer();
				for (int x = 0; x < w; x++) {
					int color = pixels[y * w + x];
					int blue = color & 0xff;
					int green = (color >> 8) & 0xff;
					int red = (color >> 16) & 0xff;
					int alpha = color >> 24;
					int value = red | (green << 8) | (blue << 16) | (alpha << 24);
					outBuffer[i++] = (byte) red;
					outBuffer[i++] = (byte) green;
					outBuffer[i++] = (byte) blue;
					outBuffer[i++] = (byte) alpha;
				}
			}

			// write
			String name = filename.substring(0, filename.length() - 4);
			FileOutputStream out = new FileOutputStream(name + ".raw");
			out.write(outBuffer);
			out.close();
		} catch (IOException e) {
			System.out.println("error while writing");
			e.printStackTrace();
		}
	}
}
